import atexit
from contextlib import ExitStack
from importlib import resources

_file_manager = ExitStack()
atexit.register(_file_manager.close)
_data_resource = resources.files("mols2grid") / "data/"
datapath = _file_manager.enter_context(resources.as_file(_data_resource))

SOLUBILITY_SDF = str(datapath / "solubility.test.sdf")



from mols2grid import datafiles as datafiles
from mols2grid._version import __version__ as __version__
from mols2grid.callbacks import make_popup_callback as make_popup_callback
from mols2grid.dispatch import display as display
from mols2grid.dispatch import save as save
from mols2grid.molgrid import MolGrid as MolGrid
from mols2grid.select import get_selection as get_selection
from mols2grid.select import list_grids as list_grids
from mols2grid.utils import sdf_to_dataframe as sdf_to_dataframe

try:
    from google.colab import output
except ImportError:
    pass
else:
    output.enable_custom_widget_manager()
